#!/bin/bash

# hwpack.sh - Lexbuilder IBS hardware pack build tool wrapper
#
# Author: James Westby <james.westby@linaro.org>
# Date  : 2 September 2010
#

Buildtool_setup() {
    Catch_faults permit_errors

    sudo apt-get update -o Acquire::http::No-Cache=True
    ERROR=$?
    if [ "${ERROR}" != "0" ]; then
        Error "Error running apt-get update in preperation of getting latest linaro-image-tools"
        Die
    fi
    
    IBS_BUILDTOOL_VERSION="${IBS_BUILDTOOL_VERSION:-*}"
    sudo apt-get install -y --force-yes linaro-image-tools="${IBS_BUILDTOOL_VERSION}"
    ERROR=$?
    if [ "${ERROR}" != "0" ]; then
        Error "Error installing linaro-image-tools=${IBS_BUILDTOOL_VERSION}"
        Die
    fi

    if [ -d "${IBS_WORKDIR}/${PROJECT}/config" ]; then
        rm -rf "${IBS_WORKDIR}/${PROJECT}/config" > /dev/null 2>&1 || true
    fi

    Action "Copying project configuration directory into work directory for build"
    Export_project_config "${PROJECT}" "${IBS_WORKDIR}/${PROJECT}/config"
    Action_done

    if [ "$?" != "0" ]; then
        Error "Unable to copy project build configuration to %s" "${IBS_WORKDIR}/${PROJECT}/config"
        Die
    fi

    Catch_faults disallow_errors
}

Buildtool_build() {
    _Check_directory

    for CONFIG_FILE in config/hwpacks/*; do
        HWPACK_NAME="$(basename "${CONFIG_FILE}")"
        linaro-hwpack-create "${CONFIG_FILE}" ${BUILDNAME}
    done

    _SaveConfig

    _DESTINATION_DIRECTORY="${RESULTDIR_IMAGES}/hwpack/"
    mkdir -p "${_DESTINATION_DIRECTORY}"

    Action "Generating checksums and copying build product to results directory"
    IFS="$(echo -e '\n\r')"
    Debug "Processing binary image results"
    for FILENAME in $(find . -maxdepth 1 -type f -name "hwpack*"); do
        Save_result "binary" "hwpack" "${FILENAME}" 1
    done
    Action_done
    unset IFS

    # TODO: ability to compare hwpacks
    #produceBuildComparison hwpack

    if [ "${ARCHIVEPROJECT}" = "1" ] || [ "${ARCHIVEPROJECT}" = "enabled" ]; then
        Info "Creating archive of build work directory..."
        mkdir -p "${RESULTDIR_PROJDIR}/"
        _SaveBuildWorkDirectory
    fi
}

Buildtool_cleanup() {
    _Check_directory

    rm -rf "${IBS_WORKDIR}/${PROJECT}/"*
}

_Check_directory() {
    if [ "${PWD}" != "${IBS_WORKDIR}/${PROJECT}" ]; then
        Error "Working directory is '%s'; expected '%s'" "{$PWD}" "${IBS_WORKDIR}/${PROJECT}"
        Die
    fi
    Debug "Directory check performed and was successful; PWD: %s" "${PWD}"
}

_SaveConfig() {
    cp -a config/* "${RESULTDIR_CONFIGFILES}/"
}

_SaveBuildWorkDirectory() {
    _Check_directory

    Action "Removing generated images before archiving"
    rm hwpack*
    Action_done

    mkdir -p "${RESULTDIR_PROJDIR}/"

    Action "Generating build archive (may take awhile)"
    tar -zcf "${RESULTDIR_PROJDIR}/${PROJECT}-${BUILDNAME}.build.tgz" "${IBS_WORKDIR}/${PROJECT}" > /dev/null 2>&1
    Action_done
}
