# Copyright 2012 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

import os
import sys
import logging
from logging.handlers import WatchedFileHandler
from ConfigParser import SafeConfigParser

OFFSPRING_ROOT = os.path.abspath(
        os.path.join(os.path.dirname(__file__), '..', '..'))

CONFIG_FILE_PATH = os.path.join(
   OFFSPRING_ROOT, 'config', 'offspring.cfg')


def get_configuration(file_path=None):
    """
    Return a SafeConfigParser object having parsed the file.
    """
    config_filename = file_path
    config = SafeConfigParser()
    if not config_filename:
        if "OFFSPRING_CONFIGFILE" in os.environ:
            config_filename = os.environ["OFFSPRING_CONFIGFILE"]
        else:
            config_filename = CONFIG_FILE_PATH
    if not os.path.exists(config_filename):
        print "E: Specified configfile '%s' does not exist." % config_filename

    config.readfp(open(config_filename, "r"))

    hostname = os.uname()[1]
    config.set("DEFAULT", "hostname", hostname)
    if not config.has_option("DEFAULT", "base_dir"):
        config.set("DEFAULT", "base_dir", OFFSPRING_ROOT)
    if "USERNAME" in os.environ:
        config.set("DEFAULT", "username", os.environ["USERNAME"])
    config.set("DEFAULT", "config_filename", config_filename)
    return config


def setup_logging(path=None,
                  fmt="%(asctime)s:%(levelname)s:%(message)s",
                  datefmt="%Y-%m-%dT%H:%M:%S",
                  level=logging.DEBUG):
    """Setup a logger to write to a given path.

    When path is provided, a log handler that works correctly with logrotate
    is used.

    @param path: The path to a file to write output to.
    @return: The log handler setup for logging.
    """
    log = logging.getLogger()
    log.propagate = False
    log.setLevel(level)
    formatter = logging.Formatter(fmt, datefmt)
    handler = WatchedFileHandler(path)
    handler.setFormatter(formatter)
    log.addHandler(handler)
    return handler


def print_builder_config(config=None):
    """
    Outputs environment variables to stdout for tools to use.

    Parses the configuration, and outputs all items from the [builder] and
    [archiver] sections in the configuration.
    """
    config = config or get_configuration()
    printed = set()
    for key, value in config.items('builder'):
        sys.stdout.write('IBS_%s="%s"\n' % (key.upper(), value))
        printed.add(key)
    for key, value in config.items('archiver'):
        if key not in printed:
            sys.stdout.write('IBS_%s="%s"\n' % (key.upper(), value))
