# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

import SimpleXMLRPCServer
import threading

from offspring.networking import BasicAuthXMLRPCRequestHandler


class LexbuilderDaemon(threading.Thread):
    def __init__(self):
        threading.Thread.__init__(self)
        self.daemon = False

    def run(self):
        raise NotImplementedError


class LexbuilderXMLRPCServer(
    threading.Thread, SimpleXMLRPCServer.SimpleXMLRPCServer):

    REQUEST_OKAY, REQUEST_ERROR = (u"OKAY", u"ERROR")

    def __init__(self, addr, requestHandler=BasicAuthXMLRPCRequestHandler,
                 logRequests=True, allow_none=False, encoding="UTF-8",
                 request_timeout=60.0):
        self.request_timeout = request_timeout
        SimpleXMLRPCServer.SimpleXMLRPCServer.__init__(
            self, addr, requestHandler, logRequests, allow_none, encoding)
        threading.Thread.__init__(self)

    def run(self):
        try:
            self.serve_forever()
        finally:
            self.server_close()

    def stop(self):
        self.shutdown()

    def _dispatch(self, method, params):
        try:
            func = getattr(self, 'api_' + method)
        except AttributeError:
            raise Exception('method "%s" is not supported' % method)
        else:
            return func(*params)

    def get_request(self):
        """Get the request and client address from the socket.

        Sets timeout on socket before returning if configured.
        """
        connection, address = self.socket.accept()
        if self.request_timeout is not None:
            connection.settimeout(self.request_timeout)
        return (connection, address)
