# Copyright 2012 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

import logging

from offspring.master.bootstrap import LexbuilderMasterBootstrap
from offspring.master.master import LexbuilderMaster

from offspring.tests.helpers import CaptureLoggingTestCase
from offspring.master.tests.helpers import (
    LexbuilderMasterTestMixin)
from offspring.config import setup_logging


class TestLexbuilderMasterBootstrap(LexbuilderMasterTestMixin,
                                    CaptureLoggingTestCase):
    """
    Tests for the LexbuilderMasterBootstrap class.
    """
    def test_create_master_bootstrap(self):
        """
        It should be possible to create a LexbuilderMasterBootstrap.
        """
        bootstrap = LexbuilderMasterBootstrap("options", self.config)
        self.assertEqual("options", bootstrap.options)

    def test_main_with_debug_mode(self):
        """
        In debug mode, the LexbuilderMasterBootstrap should not daemonize.
        """
        stdout_mock = self.mocker.replace("sys.stdout")
        stdout_mock.write("Starting offspring-master.\n")
        master_mock = self.mocker.patch(LexbuilderMaster)
        master_mock.start()

        bootstrap_mock = self.mocker.patch(LexbuilderMasterBootstrap)
        self.expect(bootstrap_mock.daemonize()).count(0)

        options_mock = self.mocker.mock()
        options_mock.debug_mode
        self.mocker.result(True)

        self.mocker.replay()

        bootstrap = LexbuilderMasterBootstrap(options_mock, self.config)
        bootstrap.main()

    def test_main_with_no_debug_mode(self):
        """
        The LexbuilderMasterBootstrap should daemonize if not running in debug
        mode.
        """
        stdout_mock = self.mocker.replace("sys.stdout")
        stdout_mock.write("Starting offspring-master.\n")

        master_mock = self.mocker.patch(LexbuilderMaster)
        master_mock.start()

        bootstrap_mock = self.mocker.patch(LexbuilderMasterBootstrap)
        self.expect(bootstrap_mock.daemonize()).count(1)

        options_mock = self.mocker.mock()
        options_mock.debug_mode
        self.mocker.result(False)

        self.mocker.replay()

        bootstrap = LexbuilderMasterBootstrap(options_mock, self.config)
        bootstrap.main()
