# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from datetime import datetime

from storm import tz
from storm.locals import create_database, Store

from offspring.master.models import BuildRequest, DailyBuildOrder, Project
from offspring.config import get_configuration


def build_active_projects(db_store=None):
    """Queue up all active projects to be built."""
    if not db_store:
        config = get_configuration()
        database = create_database(config.get("master", "db"))
        db_store = Store(database)
    activeProjects = db_store.find(Project, Project.is_active == True)
    for project in activeProjects:
        request = BuildRequest(project, project.priority, u"Nightly build")
        db_store.add(request)
    db_store.commit()


def process_pending_build_orders(db_store=None):
    """Queue up projects to be built per any pending daily build orders."""
    # NOTE: Should this build inactive projects?
    if not db_store:
        config = get_configuration()
        database = create_database(config.get("master", "db"))
        db_store = Store(database)
    orders = db_store.find(
        DailyBuildOrder,
        DailyBuildOrder.hour == datetime.now(tz.tzlocal()).hour)
    for order in orders:
        for project in order.projects:
            request = BuildRequest(project, project.priority, u"Daily build")
            db_store.add(request)
            db_store.commit()
