# Copyright 2012 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

import logging
import sys
from cStringIO import StringIO

from mocker import ANY

from offspring.slave.bootstrap import LexbuilderSlaveBootstrap
from offspring.slave.slave import LexbuilderSlave, LexbuilderSlaveServer

from offspring.slave.tests.helpers import LexbuilderSlaveTestMixin, SLAVE_PORT
from offspring.tests.helpers import CaptureLoggingTestCase


class TestLexbuilderSlave(LexbuilderSlaveTestMixin, CaptureLoggingTestCase):
    """
    Tests for the LexbuilderSlaveBootstrap class.
    """

    def test_create_slave_bootstrap(self):
        """
        It should be possible to create a LexbuilderSlaveBootstrap.
        """
        bootstrap = LexbuilderSlaveBootstrap("options", self.config)
        self.assertEqual("options", bootstrap.options)
        self.assertEqual(SLAVE_PORT, bootstrap.port)
        self.assertEqual("", bootstrap.host)

    def test_main_with_debug_mode(self):
        """
        In debug mode, the LexbuilderSlaveBootstrap should not daemonize.
        """
        stdout_mock = self.mocker.replace("sys.stdout")
        stdout_mock.write("Starting offspring-slave on :%d.\n" % SLAVE_PORT)
        slave_mock = self.mocker.patch(LexbuilderSlave)
        slave_mock.start()

        slave_server_mock = self.mocker.replace(LexbuilderSlaveServer)
        slave_server_mock(ANY, ("", SLAVE_PORT), self.config)

        bootstrap_mock = self.mocker.patch(LexbuilderSlaveBootstrap)
        self.expect(bootstrap_mock.daemonize()).count(0)

        options_mock = self.mocker.mock()
        options_mock.debug_mode
        self.mocker.result(True)

        self.mocker.replay()

        bootstrap = LexbuilderSlaveBootstrap(options_mock, self.config)
        bootstrap.main()

    def dont_main_with_no_debug_mode(self):
        """
        The LexbuilderSlaveBootstrap should daemonize if not running in debug
        mode.
        """
        bootstrap_mock = self.mocker.patch(LexbuilderSlaveBootstrap)
        self.expect(bootstrap_mock.daemonize()).count(1)

        slave_mock = self.mocker.patch(LexbuilderSlave)
        slave_mock.start()

        slave_server_mock = self.mocker.replace(LexbuilderSlaveServer)
        slave_server_mock(ANY, ("", SLAVE_PORT), self.config)

        options_mock = self.mocker.mock()
        options_mock.debug_mode
        self.mocker.result(False)

        self.mocker.replay()

        bootstrap = LexbuilderSlaveBootstrap(options_mock, self.config)
        bootstrap.main()
