# Copyright 2011 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).
import logging
from cStringIO import StringIO

from mocker import MockerTestCase


class CaptureLoggingTestCase(MockerTestCase):

    def setUp(self):
        super(CaptureLoggingTestCase, self).setUp()
        self.loggers = []

    def tearDown(self):
        for logger, handler, old_level in reversed(self.loggers):
            logger.removeHandler(handler)
            logger.setLevel(old_level)
        super(CaptureLoggingTestCase, self).tearDown()

    def capture_logging(self, logger_name="", log_level=logging.INFO,
                        format=""):
        """
        Call this with an optional logger_name and this will log the named
        logger into a log_file (StringIO) that is returned.
        """
        log_file = StringIO()
        log_handler = logging.StreamHandler(log_file)
        logger = logging.getLogger(logger_name)
        logger.addHandler(log_handler)

        if format:
            log_handler.setFormatter(logging.Formatter(format))

        old_logger_level = logger.level
        if log_level:
            logger.setLevel(log_level)
        self.loggers.append((logger, log_handler, old_logger_level))
        return log_file
