# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).
from datetime import datetime, timedelta

from offspring.web.queuemanager.models import BuildResult


def get_build_result_metrics():
    """
    Return some simple metrics, in a format suitable for iterating over and
    displaying in a command-line tool.
    """
    results = []
    start_date = datetime.utcnow()

    seven_days = (start_date - timedelta(days=7), start_date)
    thirty_days = (start_date - timedelta(days=30), start_date)
    ninety_days = (start_date - timedelta(days=90), start_date)

    build_types = [("scheduled", True), ("requested", False)]
    build_periods = [("7 days", seven_days), ("30 days", thirty_days),
                     ("90 days", ninety_days)]
    metrics = [(BuildResult.metrics.get_average_build_time, "build"),
               (BuildResult.metrics.get_average_queue_time, "queue")]

    for build_type, automated in build_types:
        for function, metric_type in metrics:
            for text, period in build_periods:
                metric = "Average %s %s time (%s)" % (build_type, metric_type,
                                                      text)
                results.append((metric,
                                function(period=period, automated=automated)))

    return results
