# encoding: utf-8
import datetime
from south.db import db
from south.v2 import SchemaMigration
from django.db import models

class Migration(SchemaMigration):

    def forwards(self, orm):
        # Adding model 'ProjectGroup'
        db.create_table('projectgroups', (
            ('name', self.gf('django.db.models.fields.CharField')(unique=True, max_length=200, primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=200)),
        ))
        db.send_create_signal('queuemanager', ['ProjectGroup'])

        # Adding model 'Project'
        db.create_table('projects', (
            ('name', self.gf('django.db.models.fields.SlugField')(unique=True, max_length=200, primary_key=True, db_index=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=30)),
            ('project_group', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['queuemanager.ProjectGroup'], null=True, blank=True)),
            ('priority', self.gf('django.db.models.fields.IntegerField')(default=50)),
            ('is_active', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('arch', self.gf('django.db.models.fields.CharField')(max_length=10)),
            ('suite', self.gf('django.db.models.fields.CharField')(max_length=200, blank=True)),
            ('series', self.gf('django.db.models.fields.CharField')(default='lucid', max_length=200)),
            ('launchpad_project', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['queuemanager.LaunchpadProject'], null=True, blank=True)),
            ('status', self.gf('django.db.models.fields.CharField')(max_length=200, null=True)),
            ('config_url', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('notes', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
        ))
        db.send_create_signal('queuemanager', ['Project'])

        # Adding model 'Lexbuilder'
        db.create_table('lexbuilders', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.SlugField')(unique=True, max_length=200, db_index=True)),
            ('uri', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('current_state', self.gf('django.db.models.fields.CharField')(default='UNKNOWN', max_length=200)),
            ('previous_state', self.gf('django.db.models.fields.CharField')(default='UNKNOWN', max_length=200)),
            ('created_at', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('updated_at', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, blank=True)),
            ('is_active', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('is_okay', self.gf('django.db.models.fields.BooleanField')(default=True)),
            ('machine_type', self.gf('django.db.models.fields.CharField')(default='x86_64', max_length=200)),
            ('current_job', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['queuemanager.BuildResult'], null=True, db_column='current_job_id', blank=True)),
            ('notes', self.gf('django.db.models.fields.TextField')(null=True, blank=True)),
        ))
        db.send_create_signal('queuemanager', ['Lexbuilder'])

        # Adding model 'BuildResult'
        db.create_table('buildresults', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=200, null=True, blank=True)),
            ('project', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['queuemanager.Project'], db_column='project_name')),
            ('builder', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['queuemanager.Lexbuilder'], null=True, blank=True)),
            ('started_at', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('finished_at', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('result', self.gf('django.db.models.fields.CharField')(max_length=200, null=True)),
            ('requestor', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'], null=True, db_column='requestor_id', blank=True)),
            ('reason', self.gf('django.db.models.fields.CharField')(max_length=200, null=True, blank=True)),
            ('requested_at', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, null=True, blank=True)),
            ('dispatched_at', self.gf('django.db.models.fields.DateTimeField')(null=True, blank=True)),
            ('notes', self.gf('django.db.models.fields.CharField')(max_length=200, null=True, blank=True)),
        ))
        db.send_create_signal('queuemanager', ['BuildResult'])

        # Adding model 'BuildRequest'
        db.create_table('buildrequests', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('project', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['queuemanager.Project'], db_column='project_name')),
            ('requestor', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'], null=True, db_column='requestor_id', blank=True)),
            ('created_at', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('score', self.gf('django.db.models.fields.IntegerField')(default=10)),
            ('reason', self.gf('django.db.models.fields.TextField')(max_length=200, blank=True)),
        ))
        db.send_create_signal('queuemanager', ['BuildRequest'])

        # Adding model 'DailyBuildOrder'
        db.create_table('dailybuildorders', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('hour', self.gf('django.db.models.fields.PositiveIntegerField')()),
        ))
        db.send_create_signal('queuemanager', ['DailyBuildOrder'])

        # Adding M2M table for field projects on 'DailyBuildOrder'
        db.create_table('dailybuildorders_projects', (
            ('id', models.AutoField(verbose_name='ID', primary_key=True, auto_created=True)),
            ('dailybuildorder', models.ForeignKey(orm['queuemanager.dailybuildorder'], null=False)),
            ('project', models.ForeignKey(orm['queuemanager.project'], null=False))
        ))
        db.create_unique('dailybuildorders_projects', ['dailybuildorder_id', 'project_id'])

        # Adding model 'LaunchpadProject'
        db.create_table('launchpad_projects', (
            ('name', self.gf('django.db.models.fields.CharField')(unique=True, max_length=200, primary_key=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=200, null=True, blank=True)),
        ))
        db.send_create_signal('queuemanager', ['LaunchpadProject'])

        # Adding model 'LaunchpadProjectMilestone'
        db.create_table('launchpad_project_milestones', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('launchpad_project', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['queuemanager.LaunchpadProject'], null=True, blank=True)),
            ('title', self.gf('django.db.models.fields.CharField')(max_length=200, blank=True)),
            ('date_targeted', self.gf('django.db.models.fields.DateField')(default=None, null=True, blank=True)),
            ('active', self.gf('django.db.models.fields.BooleanField')(default=True)),
        ))
        db.send_create_signal('queuemanager', ['LaunchpadProjectMilestone'])

        # Adding model 'ProjectNotificationSubscription'
        db.create_table('project_notification_subscriptions', (
            ('id', self.gf('django.db.models.fields.AutoField')(primary_key=True)),
            ('user', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'], db_column='user_id')),
            ('project', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['queuemanager.Project'], db_column='project_name')),
        ))
        db.send_create_signal('queuemanager', ['ProjectNotificationSubscription'])

        # Adding model 'Release'
        db.create_table('releases', (
            ('build', self.gf('django.db.models.fields.related.OneToOneField')(to=orm['queuemanager.BuildResult'], unique=True, primary_key=True)),
            ('name', self.gf('django.db.models.fields.CharField')(max_length=200)),
            ('milestone', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['queuemanager.LaunchpadProjectMilestone'], null=True, blank=True)),
            ('tag', self.gf('django.db.models.fields.CharField')(max_length=5, null=True, blank=True)),
            ('creator', self.gf('django.db.models.fields.related.ForeignKey')(to=orm['auth.User'])),
            ('created_at', self.gf('django.db.models.fields.DateTimeField')(auto_now_add=True, blank=True)),
            ('updated_at', self.gf('django.db.models.fields.DateTimeField')(auto_now=True, blank=True)),
            ('published_at', self.gf('django.db.models.fields.DateTimeField')(null=True)),
            ('checklist_url', self.gf('django.db.models.fields.URLField')(max_length=200, blank=True)),
            ('notes', self.gf('django.db.models.fields.TextField')(blank=True)),
            ('status', self.gf('django.db.models.fields.PositiveSmallIntegerField')(default=0)),
        ))
        db.send_create_signal('queuemanager', ['Release'])


    def backwards(self, orm):
        
        # Deleting model 'ProjectGroup'
        db.delete_table('projectgroups')

        # Deleting model 'Project'
        db.delete_table('projects')

        # Deleting model 'Lexbuilder'
        db.delete_table('lexbuilders')

        # Deleting model 'BuildResult'
        db.delete_table('buildresults')

        # Deleting model 'BuildRequest'
        db.delete_table('buildrequests')

        # Deleting model 'DailyBuildOrder'
        db.delete_table('dailybuildorders')

        # Removing M2M table for field projects on 'DailyBuildOrder'
        db.delete_table('dailybuildorders_projects')

        # Deleting model 'LaunchpadProject'
        db.delete_table('launchpad_projects')

        # Deleting model 'LaunchpadProjectMilestone'
        db.delete_table('launchpad_project_milestones')

        # Deleting model 'ProjectNotificationSubscription'
        db.delete_table('project_notification_subscriptions')

        # Deleting model 'Release'
        db.delete_table('releases')


    models = {
        'auth.group': {
            'Meta': {'object_name': 'Group'},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '80'}),
            'permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'})
        },
        'auth.permission': {
            'Meta': {'ordering': "('content_type__app_label', 'content_type__model', 'codename')", 'unique_together': "(('content_type', 'codename'),)", 'object_name': 'Permission'},
            'codename': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'content_type': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['contenttypes.ContentType']"}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '50'})
        },
        'auth.user': {
            'Meta': {'object_name': 'User'},
            'date_joined': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'email': ('django.db.models.fields.EmailField', [], {'max_length': '75', 'blank': 'True'}),
            'first_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'groups': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Group']", 'symmetrical': 'False', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_staff': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'is_superuser': ('django.db.models.fields.BooleanField', [], {'default': 'False'}),
            'last_login': ('django.db.models.fields.DateTimeField', [], {'default': 'datetime.datetime.now'}),
            'last_name': ('django.db.models.fields.CharField', [], {'max_length': '30', 'blank': 'True'}),
            'password': ('django.db.models.fields.CharField', [], {'max_length': '128'}),
            'user_permissions': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['auth.Permission']", 'symmetrical': 'False', 'blank': 'True'}),
            'username': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '30'})
        },
        'contenttypes.contenttype': {
            'Meta': {'ordering': "('name',)", 'unique_together': "(('app_label', 'model'),)", 'object_name': 'ContentType', 'db_table': "'django_content_type'"},
            'app_label': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'model': ('django.db.models.fields.CharField', [], {'max_length': '100'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '100'})
        },
        'queuemanager.buildrequest': {
            'Meta': {'object_name': 'BuildRequest', 'db_table': "'buildrequests'"},
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'project': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['queuemanager.Project']", 'db_column': "'project_name'"}),
            'reason': ('django.db.models.fields.TextField', [], {'max_length': '200', 'blank': 'True'}),
            'requestor': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'null': 'True', 'db_column': "'requestor_id'", 'blank': 'True'}),
            'score': ('django.db.models.fields.IntegerField', [], {'default': '10'})
        },
        'queuemanager.buildresult': {
            'Meta': {'object_name': 'BuildResult', 'db_table': "'buildresults'"},
            'builder': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['queuemanager.Lexbuilder']", 'null': 'True', 'blank': 'True'}),
            'dispatched_at': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'finished_at': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'}),
            'notes': ('django.db.models.fields.CharField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'}),
            'project': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['queuemanager.Project']", 'db_column': "'project_name'"}),
            'reason': ('django.db.models.fields.CharField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'}),
            'requested_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'null': 'True', 'blank': 'True'}),
            'requestor': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'null': 'True', 'db_column': "'requestor_id'", 'blank': 'True'}),
            'result': ('django.db.models.fields.CharField', [], {'max_length': '200', 'null': 'True'}),
            'started_at': ('django.db.models.fields.DateTimeField', [], {'null': 'True', 'blank': 'True'})
        },
        'queuemanager.dailybuildorder': {
            'Meta': {'object_name': 'DailyBuildOrder', 'db_table': "'dailybuildorders'"},
            'hour': ('django.db.models.fields.PositiveIntegerField', [], {}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'projects': ('django.db.models.fields.related.ManyToManyField', [], {'to': "orm['queuemanager.Project']", 'symmetrical': 'False'})
        },
        'queuemanager.launchpadproject': {
            'Meta': {'object_name': 'LaunchpadProject', 'db_table': "'launchpad_projects'"},
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '200', 'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200', 'null': 'True', 'blank': 'True'})
        },
        'queuemanager.launchpadprojectmilestone': {
            'Meta': {'object_name': 'LaunchpadProjectMilestone', 'db_table': "'launchpad_project_milestones'"},
            'active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'date_targeted': ('django.db.models.fields.DateField', [], {'default': 'None', 'null': 'True', 'blank': 'True'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'launchpad_project': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['queuemanager.LaunchpadProject']", 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200', 'blank': 'True'})
        },
        'queuemanager.lexbuilder': {
            'Meta': {'object_name': 'Lexbuilder', 'db_table': "'lexbuilders'"},
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'current_job': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['queuemanager.BuildResult']", 'null': 'True', 'db_column': "'current_job_id'", 'blank': 'True'}),
            'current_state': ('django.db.models.fields.CharField', [], {'default': "'UNKNOWN'", 'max_length': '200'}),
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'is_okay': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'machine_type': ('django.db.models.fields.CharField', [], {'default': "'x86_64'", 'max_length': '200'}),
            'name': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '200', 'db_index': 'True'}),
            'notes': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'previous_state': ('django.db.models.fields.CharField', [], {'default': "'UNKNOWN'", 'max_length': '200'}),
            'updated_at': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'}),
            'uri': ('django.db.models.fields.CharField', [], {'max_length': '200'})
        },
        'queuemanager.project': {
            'Meta': {'object_name': 'Project', 'db_table': "'projects'"},
            'arch': ('django.db.models.fields.CharField', [], {'max_length': '10'}),
            'config_url': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'is_active': ('django.db.models.fields.BooleanField', [], {'default': 'True'}),
            'launchpad_project': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['queuemanager.LaunchpadProject']", 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.SlugField', [], {'unique': 'True', 'max_length': '200', 'primary_key': 'True', 'db_index': 'True'}),
            'notes': ('django.db.models.fields.TextField', [], {'null': 'True', 'blank': 'True'}),
            'priority': ('django.db.models.fields.IntegerField', [], {'default': '50'}),
            'project_group': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['queuemanager.ProjectGroup']", 'null': 'True', 'blank': 'True'}),
            'series': ('django.db.models.fields.CharField', [], {'default': "'lucid'", 'max_length': '200'}),
            'status': ('django.db.models.fields.CharField', [], {'max_length': '200', 'null': 'True'}),
            'suite': ('django.db.models.fields.CharField', [], {'max_length': '200', 'blank': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '30'})
        },
        'queuemanager.projectgroup': {
            'Meta': {'object_name': 'ProjectGroup', 'db_table': "'projectgroups'"},
            'name': ('django.db.models.fields.CharField', [], {'unique': 'True', 'max_length': '200', 'primary_key': 'True'}),
            'title': ('django.db.models.fields.CharField', [], {'max_length': '200'})
        },
        'queuemanager.projectnotificationsubscription': {
            'Meta': {'object_name': 'ProjectNotificationSubscription', 'db_table': "'project_notification_subscriptions'"},
            'id': ('django.db.models.fields.AutoField', [], {'primary_key': 'True'}),
            'project': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['queuemanager.Project']", 'db_column': "'project_name'"}),
            'user': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']", 'db_column': "'user_id'"})
        },
        'queuemanager.release': {
            'Meta': {'object_name': 'Release', 'db_table': "'releases'"},
            'build': ('django.db.models.fields.related.OneToOneField', [], {'to': "orm['queuemanager.BuildResult']", 'unique': 'True', 'primary_key': 'True'}),
            'checklist_url': ('django.db.models.fields.URLField', [], {'max_length': '200', 'blank': 'True'}),
            'created_at': ('django.db.models.fields.DateTimeField', [], {'auto_now_add': 'True', 'blank': 'True'}),
            'creator': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['auth.User']"}),
            'milestone': ('django.db.models.fields.related.ForeignKey', [], {'to': "orm['queuemanager.LaunchpadProjectMilestone']", 'null': 'True', 'blank': 'True'}),
            'name': ('django.db.models.fields.CharField', [], {'max_length': '200'}),
            'notes': ('django.db.models.fields.TextField', [], {'blank': 'True'}),
            'published_at': ('django.db.models.fields.DateTimeField', [], {'null': 'True'}),
            'status': ('django.db.models.fields.PositiveSmallIntegerField', [], {'default': '0'}),
            'tag': ('django.db.models.fields.CharField', [], {'max_length': '5', 'null': 'True', 'blank': 'True'}),
            'updated_at': ('django.db.models.fields.DateTimeField', [], {'auto_now': 'True', 'blank': 'True'})
        }
    }

    complete_apps = ['queuemanager']
