# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).
"""Time in seconds formatting."""

from django.template import Library

register = Library()

ONE_MINUTE = 60
ONE_HOUR = 60 * ONE_MINUTE
ONE_DAY = 24 * ONE_HOUR


@register.filter
def seconds_to_time(value):
    """
    Converts seconds to a time representation.

    If value is None, return "Unknown"
    """
    if value is None:
        return "Unknown"

    try:
        value = float(value)
        days, remainder = divmod(value, ONE_DAY)
        hours, remainder = divmod(remainder, ONE_HOUR)
        minutes, seconds = divmod(remainder, ONE_MINUTE)

        times = [(days, "days"), (hours, "hours"), (minutes, "minutes"),
                 (seconds, "seconds")]

        periods = ["%d %s" % (time, period) for time, period in times
                   if time > 0]

        return ", ".join(periods)
    except ValueError:
        return value

seconds_to_time.is_safe = True
