# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from django.template import Template, Context
from django.test import TestCase

from offspring.web.queuemanager.templatetags.format_seconds import (
    seconds_to_time)


class TestSecondsToTimeFilter(TestCase):

    def test_seconds_to_time_seconds(self):
        """
        seconds_to_time should render the number of seconds accurately.
        """
        self.assertEqual("35 seconds", seconds_to_time(35))

    def test_seconds_to_time_with_none(self):
        """
        seconds_to_time should return Unknown if the time period is None.
        """
        self.assertEqual("Unknown", seconds_to_time(None))

    def test_seconds_to_time_with_string(self):
        """
        seconds_to_time should pass strings that can't be converted to floating
        point numbers unchanged.
        """
        self.assertEqual("Unknown", seconds_to_time("Unknown"))

    def test_seconds_to_time_minutes(self):
        """
        seconds_to_time should render the number of minutes accurately.
        """
        self.assertEqual("10 minutes", seconds_to_time(600))

    def test_seconds_to_time_hours(self):
        """
        seconds_to_time should render the number of hours accurately.
        """
        self.assertEqual("2 hours", seconds_to_time(7200))

    def test_seconds_to_time_days(self):
        """
        seconds_to_time should render the number of hours accurately.
        """
        self.assertEqual("3 days", seconds_to_time(72 * 60 * 60))

    def test_seconds_to_time_period(self):
        """
        seconds_to_time should render the time period accurately.
        """
        # 2 days, 2 hours, 10 minutes, 35 seconds
        seconds = (2 * 24 * 60 * 60) + 7200 + 600 + 35
        self.assertEqual("2 days, 2 hours, 10 minutes, 35 seconds",
                         seconds_to_time(seconds))

    def test_seconds_to_time_filter_in_template(self):
        """
        The seconds_to_time filter converts an integer value for a number of
        seconds to a human readable duration.
        """
        rendered = Template("{% load format_seconds %}"
                            "{{ 600|seconds_to_time }}").render(Context())
        self.assertTrue("10 minutes" in rendered, "Time incorrectly rendered.")
