# Copyright 2010 Canonical Ltd.  This software is licensed under the
# GNU Affero General Public License version 3 (see the file LICENSE).

from datetime import datetime, timedelta, date, time

from offspring.enums import ProjectBuildStates
from offspring.web.queuemanager.tests.factory import factory

def create_build_results_with_durations(project, durations,
                                        requestor=None,
                                        build_date=date.today(),
                                        builder=None,
                                        result=ProjectBuildStates.SUCCESS):
    """
    Create BuildResults with durations specified.

    project: The Project to associate the BuildResults with.
    durations: A sequence of time periods in minutes.

    Returns the average of the durations specified.
    """
    started_at = datetime.combine(build_date, datetime.now().time())
    total = 0
    for minutes in durations:
        total += minutes
        factory.make_build_result(
            project=project, requestor=requestor, result=result,
            finished_at=started_at + timedelta(minutes=minutes),
            started_at=started_at, builder=builder)
    return float(total) / float(len(durations))

def create_build_results_with_queue_times(project, queue_times, requestor=None,
                                          build_date=date.today()):
    """
    Create BuildResults with queue times specified.

    project: The Project to associate the BuildResults with.
    queue_times: A sequence of time periods in minutes.

    Returns the average of the queue_times specified.
    """
    dispatched_at = datetime.combine(build_date, time())
    total = 0
    for minutes in queue_times:
        total += minutes
        factory.make_build_result(
            project=project, requestor=requestor,
            requested_at=dispatched_at - timedelta(minutes=minutes),
            dispatched_at=dispatched_at)
    return float(total) / float(len(queue_times))
